]> git.sesse.net Git - nageru/blobdiff - mixer.h
Switch to getting bmusb from a submodule.
[nageru] / mixer.h
diff --git a/mixer.h b/mixer.h
index 96613f99b2a3d6a0684559e30ce4c8ee244ff891..6098222c390d9b059561900f8c826aeb5f2ffcb4 100644 (file)
--- a/mixer.h
+++ b/mixer.h
@@ -9,12 +9,13 @@
 #include <movit/flat_input.h>
 #include <functional>
 
-#include "bmusb.h"
+#include "bmusb/bmusb.h"
 #include "h264encode.h"
 #include "pbo_frame_allocator.h"
 #include "ref_counted_frame.h"
 #include "ref_counted_gl_sync.h"
 #include "theme.h"
+#include "resampler.h"
 
 #define NUM_CARDS 2
 
@@ -32,18 +33,16 @@ public:
        void start();
        void quit();
 
-       enum Source {
-               SOURCE_INPUT1,
-               SOURCE_INPUT2,
-               SOURCE_SBS,
-       };
-       void cut(Source source);
+       void transition_clicked(int transition_num);
+       void channel_clicked(int preview_num);
 
        enum Output {
                OUTPUT_LIVE = 0,
                OUTPUT_PREVIEW,
                OUTPUT_INPUT0,
                OUTPUT_INPUT1,
+               OUTPUT_INPUT2,
+               OUTPUT_INPUT3,
                NUM_OUTPUTS
        };
 
@@ -79,6 +78,11 @@ public:
                output_channel[output].set_frame_ready_callback(callback);
        }
 
+       std::vector<std::string> get_transition_names()
+       {
+               return theme->get_transition_names(frame / 60.0);
+       }
+
 private:
        void bm_frame(int card_index, uint16_t timecode,
                FrameAllocator::Frame video_frame, size_t video_offset, uint16_t video_format,
@@ -92,21 +96,12 @@ private:
        std::unique_ptr<movit::ResourcePool> resource_pool;
        std::unique_ptr<Theme> theme;
        std::unique_ptr<movit::EffectChain> display_chain;
-       std::unique_ptr<movit::EffectChain> preview0_chain;
-       std::unique_ptr<movit::EffectChain> preview1_chain;
        GLuint cbcr_program_num;  // Owned by <resource_pool>.
        std::unique_ptr<H264Encoder> h264_encoder;
 
        // Effects part of <display_chain>. Owned by <display_chain>.
        movit::FlatInput *display_input;
 
-       // Effects part of <preview0_chain>. Owned by <preview0_chain>.
-       movit::YCbCrInput *preview0_input;
-
-       // Effects part of <preview1_chain>. Owned by <preview1_chain>.
-       movit::YCbCrInput *preview1_input;
-
-       Source current_source = SOURCE_INPUT1;
        int frame = 0;
 
        std::mutex bmusb_mutex;
@@ -114,15 +109,17 @@ private:
                BMUSBCapture *usb;
                std::unique_ptr<PBOFrameAllocator> frame_allocator;
 
-               // Threading stuff
-               bool thread_initialized = false;
+               // Stuff for the OpenGL context (for texture uploading).
                QSurface *surface;
                QOpenGLContext *context;
 
-               bool new_data_ready = false;  // Whether new_frame contains anything.
+               bool new_data_ready = false;  // Whether new_frame and new_frame_audio contains anything.
+               bool should_quit = false;
                RefCountedFrame new_frame;
                GLsync new_data_ready_fence;  // Whether new_frame is ready for rendering.
+               std::vector<float> new_frame_audio;
                std::condition_variable new_data_ready_changed;  // Set whenever new_data_ready is changed.
+               Resampler *resampler = nullptr;
        };
        CaptureCard cards[NUM_CARDS];  // protected by <bmusb_mutex>
 
@@ -130,6 +127,7 @@ private:
 
        class OutputChannel {
        public:
+               ~OutputChannel();
                void output_frame(DisplayFrame frame);
                bool get_display_frame(DisplayFrame *frame);
                void set_frame_ready_callback(new_frame_ready_callback_t callback);